/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright (C) 2008 Luigi Ziviani <ziviani_luigi@yahoo.it> All Rights Reserved.*
*********************************************************************************
* Id: mimetypedialog.cpp,   v 1.0                      2008/01/01               *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <xincs.h>
#include <fx.h>
#include "MimeTypeDialog.h"
#include "fxmoviemanager.h"
#include "icons.h"


FXDEFMAP(MimeTypeDialog) MimeTypeDialogMap[]={
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_ICONPATH,		MimeTypeDialog::onCmdSelectIconPath),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_COMMAND,		MimeTypeDialog::onCmdSelectCommand),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_MIMETYPE,		MimeTypeDialog::onCmdSelectMimeType),
  FXMAPFUNC(SEL_CLOSE,	MimeTypeDialog::ID_FXMMAPPLICATION,		MimeTypeDialog::onCmdCloseDialog),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_CREATE_MIMEASSOCIATION,	MimeTypeDialog::onCmdCreateFileAssociation),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_DELETE_MIMEASSOCIATION,	MimeTypeDialog::onCmdDeleteFileAssociation),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_RENAME_MIMEASSOCIATION,	MimeTypeDialog::onCmdRenameFileAssociation),
  FXMAPFUNC(SEL_CHANGED,MimeTypeDialog::ID_SELECT_MIMEASSOCIATION,	MimeTypeDialog::onCmdFileAssociation),
  FXMAPFUNCS(SEL_COMMAND,MimeTypeDialog::ID_SELECT_ICON_BIGNAME,MimeTypeDialog::ID_SELECT_ICON_BIGNAMEOPEN,MimeTypeDialog::onCmdSelectIcon),
  };


// Object implementation
FXIMPLEMENT(MimeTypeDialog,FXDialogBox,MimeTypeDialogMap,ARRAYNUMBER(MimeTypeDialogMap))


// Construct window
MimeTypeDialog::MimeTypeDialog(FXWindow *own):FXDialogBox(own,"FXMovieManager Setup",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0){

  // get iconpath Settings
  iconpath  = getApp()->reg().readStringEntry("SETTINGS","iconpath");


/*******************************************************************/
  // Set Target
  setTarget(this);

  // Set Datatargets
  target_iconpath.connect(iconpath);
  target_association_type.connect(fileassociation.type);
  target_association_command.connect(fileassociation.command);
  target_association_mimetype.connect(fileassociation.mimetype);

  // Set the message identifier for this data target
  setSelector(ID_FXMMAPPLICATION);
/*******************************************************************/


  // Build icons
  logoicon=new FXPNGIcon(getApp(),fxmmlogo);
  abouticon=new FXGIFIcon(getApp(),b_list);
  conficon=new FXGIFIcon(getApp(),b_conf);
  diricon=new FXGIFIcon(getApp(),m_dir);

  // get the size of normal font and create a new font with size x 1.5
  getApp()->getNormalFont()->create();
  FXFontDesc fontdescription=getApp()->getNormalFont()->getFontDesc();
  fontdescription.size = (FXuint) (((double)fontdescription.size) * 1.5);
  titlefont = new FXFont(getApp(),fontdescription);
  titlefont->create();

  tooltip=new FXToolTip(getApp());

  // Declare reused frames
  FXHorizontalFrame *hframe=NULL;
  FXVerticalFrame   *sframe=NULL;
  FXVerticalFrame   *vframe=NULL;
  FXLabel           *label=NULL;
  FXPacker 	    *packer;

  // main frame
  FXVerticalFrame   *mainframe=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  // Get icon margin
  const FXint spacing=(logoicon ? 10 : 20);

  // Create the header
  label=new FXLabel(mainframe," FXMovieManager Configuration",logoicon,LAYOUT_FILL_X|JUSTIFY_LEFT|TEXT_AFTER_ICON,0,0,0,0,spacing,spacing,spacing,spacing);
  label->setBackColor(FXRGB(0,0,0));
  label->setTextColor(FXRGB(255,255,0));
  label->setFont(titlefont);

  new FXSeparator(mainframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  
  FXHorizontalFrame *hmainframe=new FXHorizontalFrame(mainframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
  FXVerticalFrame *buttonframe=new FXVerticalFrame(hmainframe,LAYOUT_FILL_Y|LAYOUT_LEFT|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT,0,0,0,0, 5,5,5,5);
  new FXSeparator(hmainframe,SEPARATOR_GROOVE|LAYOUT_FILL_Y);


  FXSwitcher *switcher = new FXSwitcher(hmainframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);

  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"About",abouticon,switcher,FXSwitcher::ID_OPEN_FIRST,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);
  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"HowTo",abouticon,switcher,FXSwitcher::ID_OPEN_SECOND,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);
  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"MimeType",conficon,switcher,FXSwitcher::ID_OPEN_THIRD,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);


  // About this program
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X,0,0,0,0,0,0,0,0,0,0);
  new FXLabel(hframe," About FXMovieManager",NULL,LAYOUT_CENTER_Y);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  sframe = new FXVerticalFrame(hframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,5,5,5,5,0,0);

  label = new FXLabel(vframe,
	"FXMovieManager is a FileManager with movie thumbnails,\n"
	"it manages a PlayList and act as simple front-end to MPlayer.\n"
	"Copyright (C) 2008 Luigi Ziviani (ziviani_luigi@yahoo.it).\n\n"
	"This program is free software; you can redistribute it\n"
	"and/or modify it under the terms of the GNU General Public\n"
	"License as published by the Free Software Foundation;\n"
	"either version 3 of the License, or(at your option)\n"
	"any later version.\n\n"
	"This program is distributed in the hope that it will be useful,\n"
	"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
	"See the GNU General Public License for more details.\n\n"
	"You should have received a copy of the GNU General Public License\n"
	"along with this program; if not, write to the \n"
	"Free Software Foundation, Inc.,\n"
	"59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"
	);
  label->setBackColor(FXRGB(255,255,255));
  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  // Help instructions
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X,0,0,0,0,0,0,0,0,0,0);
  new FXLabel(hframe," How to use FXMovieManager",NULL,LAYOUT_CENTER_Y);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  sframe = new FXVerticalFrame(hframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,5,5,5,5,0,0);

  label = new FXLabel(vframe,
	"To manage thumbnails of movie files a list of buttons on the\n"
	"right of the main application area can be used.\n\n"
	"* In order to show thumbnails of movie files:\n"
	"select the movies you want to display and \n"
	"press the button [Create thumbnails of selected Movies].\n\n"
	"* In order to load a movie into the playlist:\n"
	"double click on a movie in the filelist or open the file dialog\n"
	"and select one or more movies keeping [Ctrl] or [Shift] pressed.\n\n"
	"* In order to delete hidden directories that store the thumbnails:\n"
	"press the button [Show hidden directories] and then\n"
	"press the button [Delete displayed hidden directories]\n\n"
	"* In order to associate icons to file extensions in the filelist:\n"
	"pres the logo FXMM and select the button MimeType\n"
	"a dialog will be displayed where to add new file associations\n"
	);
  label->setBackColor(FXRGB(255,255,255));
  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  // Content-Types configuration
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXLabel(hframe,"Search Path for Icons:",NULL,LAYOUT_CENTER_Y);
  new FXTextField(hframe,2,&target_iconpath,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);
  new FXButton(hframe,"..",diricon,this,ID_SELECT_ICONPATH,LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y|ICON_AFTER_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
  vframe = new FXVerticalFrame(hframe,LAYOUT_FILL_Y,0,0,0,0,5,5,5,5);

  new FXSeparator(hframe,SEPARATOR_GROOVE|LAYOUT_FILL_Y);

  new FXLabel(vframe,"Extensions of File: ");
  sframe = new FXVerticalFrame(vframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
  associationlist = new FXList(sframe,this,ID_SELECT_MIMEASSOCIATION,LAYOUT_FILL_Y|LAYOUT_FILL_X|LIST_BROWSESELECT);
  associationlist->setSortFunc(FXList::ascending);
  FXHorizontalFrame * listbuttonframe = new FXHorizontalFrame(vframe,PACK_UNIFORM_WIDTH|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
  new FXButton(listbuttonframe,"&AddNew\tAdd a New Extension",NULL,this,ID_CREATE_MIMEASSOCIATION);
  new FXButton(listbuttonframe,"&Delete\tDelete an Extension",NULL,this,ID_DELETE_MIMEASSOCIATION);
  new FXButton(listbuttonframe,"&Edit\tEdit the Name of an Extension",NULL,this,ID_RENAME_MIMEASSOCIATION);

  vframe = new FXVerticalFrame(hframe,LAYOUT_FILL_Y|LAYOUT_FILL_X,0,0,0,0,0,0,0,0,0,0);


  packer = new FXPacker(vframe,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXLabel(packer,"Type Name:");
  new FXTextField(packer,2,&target_association_type,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);


  packer = new FXPacker(vframe,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXLabel(packer,"Content-Type [object/format]:");
  mimetypelist = new FXComboBox(packer,1,this,ID_SELECT_MIMETYPE,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|COMBOBOX_NO_REPLACE);
  mimetypelist->setSortFunc(FXList::ascending);
  mimetypelist->setNumVisible(9);
  mimetypelist->appendItem(" ");

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);


  packer = new FXPacker(vframe,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXLabel(packer,"Open With Command:");
  new FXButton(packer,"..",diricon,this,ID_SELECT_COMMAND,LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y|ICON_AFTER_TEXT|FRAME_RAISED|FRAME_THICK);
  new FXTextField(packer,2,&target_association_command,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);


  FXMatrix *iconsmatrix=new FXMatrix(vframe,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);
  new FXLabel(iconsmatrix,"Normal",NULL,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
  new FXLabel(iconsmatrix,"ifOpen",NULL,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
  button_bigname = new FXButton(iconsmatrix,"\tChange MIME-Type Icon",NULL,this,ID_SELECT_ICON_BIGNAME,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,64,64, 1,1,1,1);
  button_bignameopen = new FXButton(iconsmatrix,"\tChange MIME-Type Icon",NULL,this,ID_SELECT_ICON_BIGNAMEOPEN,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,64,64, 1,1,1,1);


  // import file associations **********************************************//

  FXString datastring;
  FXString mimetype;

  FXStringDict *filetypes; // The dictionary class maintains a fast-access 
                           // hash table of entities indexed by a character string.

  filetypes = getApp()->reg().find("FILETYPES"); // FILETYPES is the registry section where are contents-type data

  if(filetypes){
    for(FXint i=filetypes->first(); i<filetypes->size(); i=filetypes->next(i)){
      associationlist->appendItem(filetypes->key(i),NULL,NULL,TRUE); 	// Key string of struct FXDictEntry
      datastring = filetypes->data(i); 					// Data of struct FXDictEntry
      mimetype = datastring.section(";",3);
      if (!mimetype.empty() && (mimetypelist->findItem(mimetype)==-1)){
        mimetypelist->appendItem(mimetype);
        }
      }
    }

  associationlist->sortItems();
  mimetypelist->sortItems();

  //***********************************************************************//


  new FXSeparator(mainframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame *copyright=new FXHorizontalFrame(mainframe,LAYOUT_BOTTOM|LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  label = new FXLabel(copyright,"FXMovieManager Settings - Copyright (C) Luigi Ziviani",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
  // set the same look of separators
  label->disable();

  new FXButton(copyright,"&Quit and Save?",NULL,this,FXTopWindow::ID_CLOSE,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0,20,20);

  }


// Delete window
MimeTypeDialog::~MimeTypeDialog(){
  delete titlefont;
  delete logoicon;
  delete abouticon;
  delete conficon;
  delete diricon;
  }


// Searc for Icon and load it
static FXIcon *createIconApp(FXApp *app,const FXString& name,const FXString& iconpath){
  FXIconSource iconsource(app);
  FXIcon *icon=NULL;
  FXString fullpath;
  if(FXStat::exists(name)){
    fullpath=name;
    }
  else{
    fullpath=FXPath::search(iconpath,name);
    if(fullpath.empty()) return NULL;
    }
  icon=iconsource.loadIconFile(fullpath);
  if(icon){
    icon->blend(app->getBaseColor());
    icon->create();
    return icon;
    }
  return NULL;
  }


// Update Icon
static void updateIconApp(FXApp* app,FXButton* button,const FXString& path){
  FXIconSource iconsource(app);
  FXIcon *icon=NULL;
  if(button->getIcon()){
    icon=button->getIcon();
    button->setIcon(NULL);
    delete icon;
    icon=NULL;
    }
  icon=iconsource.loadIconFile(path);
  if(icon){
    icon->blend(app->getBaseColor());
    icon->create();
    button->setIcon(icon);
    }
  }


// Save file association entry
void MimeTypeDialog::saveFileAssociation(){
  if(fileassociation.extension.empty()) return;
  FXString entry;
  entry=fileassociation.command+";"+fileassociation.type+";";
  if(fileassociation.bignameopen.empty())
    entry+=fileassociation.bigname+";";
  else
    entry+=fileassociation.bigname+":"+fileassociation.bignameopen+";";
  entry+=fileassociation.mimetype;
  getApp()->reg().writeStringEntry("FILETYPES",fileassociation.extension.text(),entry.text());
  }


// Set search path for icons
long MimeTypeDialog::onCmdSelectIconPath(FXObject*,FXSelector,void*){
  FXString path=(iconpath.empty()) ? "/usr/share/" : iconpath.text();
  FXDirDialog opendialog(this,"Search path for icons?");
	opendialog.setDirectory(path);
	if(opendialog.execute()){
		iconpath=opendialog.getDirectory();
	}
  return 1;
  }


// Set command to open the file with
long MimeTypeDialog::onCmdSelectCommand(FXObject*,FXSelector,void*){
  FXString path=(fileassociation.command.empty()) ? "/usr/bin/" : fileassociation.command.text();
  FXString search=FXFileDialog::getOpenFilename(this,"Command to open file with?",path,"*");
  if(!search.empty()){
    fileassociation.command=search;
    }
  return 1;
  }


long MimeTypeDialog::onCmdSelectMimeType(FXObject*,FXSelector,void*ptr){
  FXString content=(FXchar*)ptr;
  if(!content.empty() && (mimetypelist->findItem(content)==-1)){
    mimetypelist->appendItem(content);
    mimetypelist->sortItems();
    }
  fileassociation.mimetype=content;
  return 1;
  }


long MimeTypeDialog::onCmdFileAssociation(FXObject*,FXSelector,void*){
  saveFileAssociation();

  FXIcon *icon;
  FXString iconname;
  FXString association;

  fileassociation.extension=associationlist->getItemText(associationlist->getCurrentItem());
  if(fileassociation.extension.empty()) return 1;

  association=getApp()->reg().readStringEntry("FILETYPES",fileassociation.extension.text());

  // here is the same association order of ControlPanel to be able to import associations 
  fileassociation.command = association.section(";",0);  // the command to open the file with

  fileassociation.type = association.section(";",1);     // the name of the type

  iconname = association.section(";",2);                 // icons (we import only big icon associations)
  fileassociation.bigname = iconname.section(":",0);
  fileassociation.bignameopen = iconname.section(":",1);

  fileassociation.mimetype = association.section(";",3); // content-type [object/format]
  if(!fileassociation.mimetype.empty()){
    FXint no=mimetypelist->findItem(fileassociation.mimetype);
    mimetypelist->setCurrentItem(no);
    }
  else {
    FXint no=mimetypelist->findItem(" ");
    mimetypelist->setCurrentItem(no);
    }

  if(button_bigname->getIcon()){
    icon=button_bigname->getIcon();
    button_bigname->setIcon(NULL);
    delete icon;
    }
  icon=createIconApp(getApp(),fileassociation.bigname,iconpath);
  button_bigname->setIcon(icon);

  if(button_bignameopen->getIcon()){
    icon=button_bignameopen->getIcon();
    button_bignameopen->setIcon(NULL);
    delete icon;
    }
  icon=createIconApp(getApp(),fileassociation.bignameopen,iconpath);
  button_bignameopen->setIcon(icon);

  return 1;
  }


long MimeTypeDialog::onCmdCreateFileAssociation(FXObject*,FXSelector,void*){
  FXString result;
  if(FXInputDialog::getString(result,this,"New File Association","Please enter fileassociation extension:",NULL)){
    if(result.empty()) return 1;
    if((associationlist->findItem(result))>=0){
      FXMessageBox::question(this,MBOX_OK,"Duplicate Association","The extension given %s already exists.",result.text());
      return 1;
      }

    // Save Old
    saveFileAssociation();

    fileassociation.extension = result;
    fileassociation.type = "";
    fileassociation.command = "";
    fileassociation.mimetype = "";
    fileassociation.bigname = "";
    fileassociation.bignameopen = "";


    // Save New
    saveFileAssociation();

    FXint no = associationlist->appendItem(fileassociation.extension);
    associationlist->setCurrentItem(no,TRUE);
    associationlist->sortItems();
    associationlist->makeItemVisible(associationlist->getCurrentItem());
    }
  return 1;
  }


long MimeTypeDialog::onCmdDeleteFileAssociation(FXObject*,FXSelector,void*){
  if(fileassociation.extension.empty()) return 1;
  if(FXMessageBox::question(this,MBOX_OK_CANCEL,"Delete Fileassociation?","Are you sure you want to delete\nthe fileassociation for %s",fileassociation.extension.text())==MBOX_CLICKED_OK){
    getApp()->reg().deleteEntry("FILETYPES",fileassociation.extension.text());
    fileassociation.extension="";
    associationlist->removeItem(associationlist->getCurrentItem(),TRUE);
    }
  return 1;
  }


long MimeTypeDialog::onCmdRenameFileAssociation(FXObject*,FXSelector,void*){
  FXint no;
  FXString result=fileassociation.extension;
  if(FXInputDialog::getString(result,this,"Rename File Association","Rename File Association",NULL)){
    if(result==fileassociation.extension) return 1;
    if((no=associationlist->findItem(result))>=0){
      if(FXMessageBox::question(this,MBOX_YES_NO,"Replace Association?","Would you like to replace the existing association?")!=MBOX_CLICKED_YES){
        return 1;
        }
      }

    // Find Extension to rename
    getApp()->reg().deleteEntry("FILETYPES",fileassociation.extension.text());
    fileassociation.extension=result;
    // Save renamed Extension 
    saveFileAssociation();
    if(no>=0){
      FXint olditem = associationlist->getCurrentItem();
      associationlist->setCurrentItem(no,TRUE);
      // Remove old Extension
      associationlist->removeItem(olditem);
      }
    else {
      associationlist->setItemText(associationlist->getCurrentItem(),fileassociation.extension);
      }
    }
  return 1;
  }


long MimeTypeDialog::onCmdSelectIcon(FXObject*,FXSelector sel,void*){
  FXString name;
    switch(FXSELID(sel)){
	case ID_SELECT_ICON_BIGNAME: name=fileassociation.bigname; break;
	case ID_SELECT_ICON_BIGNAMEOPEN: name=fileassociation.bignameopen; break;
    }

    if(!FXStat::exists(name)){
	name=FXPath::search(iconpath,name);
    }

  FXFileDialog opendialog(this,"Select the Icon");
  opendialog.setSelectMode(SELECTFILE_EXISTING);
  opendialog.setFilename(name);
  opendialog.showImages(TRUE);
  if(opendialog.execute()){

	FXString iconroot=opendialog.getFilename();
	FXString iconname=FXPath::name(iconroot);

	switch(FXSELID(sel)){
		case ID_SELECT_ICON_BIGNAME:
			updateIconApp(getApp(),button_bigname,iconroot);
			fileassociation.bigname=iconname;
		break;
		case ID_SELECT_ICON_BIGNAMEOPEN:
			updateIconApp(getApp(),button_bignameopen,iconroot);
			fileassociation.bignameopen=iconname;
		break;
	}
    }
  return 1;
  }



// Close the dialog
long MimeTypeDialog::onCmdCloseDialog(FXObject*,FXSelector,void*){

  FXint result=FXMessageBox::question(this,MBOX_SAVE_CANCEL_DONTSAVE,"Save Changes?","Do you want to save changes to the FXMovieManager Registry?\n\nThen you must restart the application for the changes to take effect.");
  if(result==MBOX_CLICKED_CANCEL){ 
	return 1;
  }
  if(result==MBOX_CLICKED_SAVE){

	saveFileAssociation();
	// Save iconpath Settings
	getApp()->reg().writeStringEntry("SETTINGS","iconpath",iconpath.text());
  }
  FXWindow::hide();
  return 1;
  }

// EOF
